summaryrefslogtreecommitdiffstats
path: root/korganizer/kotodoview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /korganizer/kotodoview.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'korganizer/kotodoview.cpp')
-rw-r--r--korganizer/kotodoview.cpp52
1 files changed, 26 insertions, 26 deletions
diff --git a/korganizer/kotodoview.cpp b/korganizer/kotodoview.cpp
index 333e2fbf5..475a2f636 100644
--- a/korganizer/kotodoview.cpp
+++ b/korganizer/kotodoview.cpp
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqlayout.h>
@@ -64,10 +64,10 @@ using namespace KOrg;
#include "calprinter.h"
#endif
-KOTodoListViewToolTip::KOTodoListViewToolTip (TQWidget *parent,
+KOTodoListViewToolTip::KOTodoListViewToolTip (TQWidget *tqparent,
Calendar *calendar,
KOTodoListView *lv )
- :TQToolTip(parent), mCalendar( calendar )
+ :TQToolTip(tqparent), mCalendar( calendar )
{
todolist=lv;
}
@@ -100,8 +100,8 @@ void KOTodoListViewToolTip::maybeTip( const TQPoint & pos)
-KOTodoListView::KOTodoListView( TQWidget *parent, const char *name )
- : KListView( parent, name ), mCalendar( 0 ), mChanger( 0 )
+KOTodoListView::KOTodoListView( TQWidget *tqparent, const char *name )
+ : KListView( tqparent, name ), mCalendar( 0 ), mChanger( 0 )
{
mOldCurrent = 0;
mMousePressed = false;
@@ -227,7 +227,7 @@ void KOTodoListView::contentsDropEvent( TQDropEvent *e )
mChanger->changeIncidence( oldTodo, existingTodo, KOGlobals::RELATION_MODIFIED, this );
mChanger->endChange( existingTodo, 0, TQString() );
} else {
- KMessageBox::sorry( this, i18n("Unable to change to-do's parent, "
+ KMessageBox::sorry( this, i18n("Unable to change to-do's tqparent, "
"because the to-do cannot be locked.") );
}
delete oldTodo;
@@ -263,7 +263,7 @@ void KOTodoListView::contentsDropEvent( TQDropEvent *e )
TQStringList emails = KPIM::splitEmailAddrList( text );
for(TQStringList::ConstIterator it = emails.begin();it!=emails.end();++it) {
kdDebug(5850) << " Email: " << (*it) << endl;
- int pos = (*it).find("<");
+ int pos = (*it).tqfind("<");
TQString name = (*it).left(pos);
TQString email = (*it).mid(pos);
if (!email.isEmpty() && todoi) {
@@ -299,7 +299,7 @@ void KOTodoListView::contentsMousePressEvent(TQMouseEvent* e)
treeStepSize() * (i->depth() + (rootIsDecorated() ? 1 : 0)) +
itemMargin() ||
p.x() < header()->sectionPos(header()->mapToIndex(0))) {
- if (e->button()==Qt::LeftButton) {
+ if (e->button()==TQt::LeftButton) {
mPressPos = e->pos();
mMousePressed = true;
}
@@ -360,8 +360,8 @@ void KOTodoListView::contentsMouseDoubleClickEvent(TQMouseEvent *e)
/////////////////////////////////////////////////////////////////////////////
-KOTodoView::KOTodoView( Calendar *calendar, TQWidget *parent, const char* name)
- : KOrg::BaseView( calendar, parent, name )
+KOTodoView::KOTodoView( Calendar *calendar, TQWidget *tqparent, const char* name)
+ : KOrg::BaseView( calendar, tqparent, name )
{
TQBoxLayout *topLayout = new TQVBoxLayout( this );
@@ -558,7 +558,7 @@ void KOTodoView::updateView()
*/
// Put for each Event a KOTodoViewItem in the list view. Don't rely on a
// specific order of events. That means that we have to generate parent items
// recursively for proper hierarchical display of Todos.
mTodoMap.clear();
Todo::List::ConstIterator it;
@@ -603,7 +603,7 @@ TQMap<Todo *,KOTodoViewItem *>::ConstIterator
// kdDebug(5850) << " has Related" << endl;
TQMap<Todo *,KOTodoViewItem *>::ConstIterator itemIterator;
- itemIterator = mTodoMap.find(relatedTodo);
+ itemIterator = mTodoMap.tqfind(relatedTodo);
if (itemIterator == mTodoMap.end()) {
// kdDebug(5850) << " related not yet in list" << endl;
itemIterator = insertTodoItem (relatedTodo);
@@ -612,7 +612,7 @@ TQMap<Todo *,KOTodoViewItem *>::ConstIterator
// and one into the map. Sure finding is more easy but why? -zecke
KOTodoViewItem *todoItem;
// in case we found a related parent, which has no KOTodoViewItem yet, this must
// be the case where 2 items refer to each other, therefore simply create item as root item
if ( *itemIterator == 0 ) {
todo->setRelatedTo(0); // break the recursion, else we will have troubles later
@@ -703,15 +703,15 @@ void KOTodoView::changeIncidenceDisplay(Incidence *incidence, int action)
scheduleRemoveTodoItem( todoItem );
} else {
// correctly update changes in relations
- Todo*parent = dynamic_cast<Todo*>( todo->relatedTo() );
- KOTodoViewItem*parentItem = 0;
- if ( parent && mTodoMap.tqcontains(parent) ) {
- parentItem = mTodoMap[ parent ];
+ Todo*tqparent = dynamic_cast<Todo*>( todo->relatedTo() );
+ KOTodoViewItem*tqparentItem = 0;
+ if ( tqparent && mTodoMap.tqcontains(tqparent) ) {
+ tqparentItem = mTodoMap[ tqparent ];
}
- if ( todoItem->parent() != parentItem ) {
+ if ( todoItem->tqparent() != tqparentItem ) {
// The relations changed
- if ( parentItem ) {
- parentItem->insertItem( todoItem );
+ if ( tqparentItem ) {
+ tqparentItem->insertItem( todoItem );
} else {
mTodoListView->insertItem( todoItem );
}
@@ -992,7 +992,7 @@ void KOTodoView::copyTodoToDate( TQDate date )
newTodo->setDtDue( dt );
newTodo->setPercentComplete( 0 );
- QPair<ResourceCalendar *, TQString>p =
+ TQPair<ResourceCalendar *, TQString>p =
CalHelper::incSubResourceCalendar( calendar(), mActiveItem->todo() );
mChanger->addIncidence( newTodo, p.first, p.second, this );
@@ -1011,7 +1011,7 @@ TQPopupMenu *KOTodoView::getCategoryPopupMenu( KOTodoViewItem *todoItem )
++it ) {
int index = tempMenu->insertItem( *it );
mCategory[ index ] = *it;
- if ( checkedCategories.find( *it ) != checkedCategories.end() )
+ if ( checkedCategories.tqfind( *it ) != checkedCategories.end() )
tempMenu->setItemChecked( index, true );
}
@@ -1030,7 +1030,7 @@ void KOTodoView::changedCategories(int index)
Todo *oldTodo = todo->clone();
TQStringList categories = todo->categories ();
- if ( categories.find( mCategory[index] ) != categories.end() )
+ if ( categories.tqfind( mCategory[index] ) != categories.end() )
categories.remove( mCategory[index] );
else
categories.insert( categories.end(), mCategory[index] );
@@ -1072,7 +1072,7 @@ void KOTodoView::setNewPercentageDelayed( KOTodoViewItem *item, int percentage )
void KOTodoView::processDelayedNewPercentage()
{
- TQValueList< QPair< KOTodoViewItem *, int> >::Iterator it;
+ TQValueList< TQPair< KOTodoViewItem *, int> >::Iterator it;
for ( it = mPercentChangedMap.begin(); it != mPercentChangedMap.end(); ++it )
setNewPercentage( (*it).first, (*it).second );
@@ -1128,7 +1128,7 @@ void KOTodoView::addQuickTodo()
delete todo;
return;
}
- mQuickAdd->setText( TQString::null );
+ mQuickAdd->setText( TQString() );
}
}
@@ -558,7 +558,7 @@ void KOTodoView::updateView()
*/
// Put for each Event a KOTodoViewItem in the list view. Don't rely on a
- // specific order of events. That means that we have to generate parent items
+ // specific order of events. That means that we have to generate tqparent items
// recursively for proper hierarchical display of Todos.
mTodoMap.clear();
@@ -612,7 +612,7 @@ TQMap<Todo *,KOTodoViewItem *>::ConstIterator
// and one into the map. Sure finding is more easy but why? -zecke
KOTodoViewItem *todoItem;
- // in case we found a related parent, which has no KOTodoViewItem yet, this must
+ // in case we found a related tqparent, which has no KOTodoViewItem yet, this must
// be the case where 2 items refer to each other, therefore simply create item as root item
if ( *itemIterator == 0 ) {